@@ -36,6 +36,7 @@
 
 #include "src/nl80211util.h"
 #include "src/iwd.h"
+#include "src/module.h"
 #include "src/netdev.h"
 #include "src/wiphy.h"
 #include "src/util.h"
@@ -46,6 +47,7 @@ static struct l_genl_family *nl80211 = NULL;
 static char **whitelist_filter;
 static char **blacklist_filter;
 static bool randomize;
+static bool use_default;
 
 struct wiphy_setup_state {
 	uint32_t id;
@@ -71,7 +73,7 @@ static const char *default_if_driver_list[] = {
 	 * many other drivers are built from the same source code so
 	 * blacklist all of them.  Unfortunately there are in-tree drivers
 	 * that also match these names and may be fine.  Use
-	 * use_default_interface to override.
+	 * UseDefaultInterface to override.
 	 */
 	"rtl81*",
 	"rtl87*",
@@ -333,8 +335,6 @@ static struct wiphy_setup_state *manager_rx_cmd_new_wiphy(
 	uint32_t id;
 	const char *name;
 	const char *driver, **driver_bad;
-	bool use_default;
-	const struct l_settings *settings = iwd_get_config();
 
 	if (nl80211_parse_attrs(msg, NL80211_ATTR_WIPHY, &id,
 					NL80211_ATTR_WIPHY_NAME, &name,
@@ -357,6 +357,8 @@ static struct wiphy_setup_state *manager_rx_cmd_new_wiphy(
 	state = l_new(struct wiphy_setup_state, 1);
 	state->id = id;
 	state->wiphy = wiphy;
+	state->use_default = use_default;
+
 	l_queue_push_tail(pending_wiphys, state);
 
 	driver = wiphy_get_driver(wiphy);
@@ -375,11 +377,6 @@ static struct wiphy_setup_state *manager_rx_cmd_new_wiphy(
 	if (whitelist_filter || blacklist_filter)
 		state->use_default = true;
 
-	/* The setting overrides our attempts to ensure things work */
-	if (l_settings_get_bool(settings, "General",
-				"use_default_interface", &use_default))
-		state->use_default = use_default;
-
 	if (state->use_default)
 		l_info("Wiphy %s will only use the default interface", name);
 
@@ -584,16 +581,18 @@ static void manager_config_notify(struct l_genl_msg *msg, void *user_data)
 	}
 }
 
-bool manager_init(struct l_genl_family *in,
-			const char *if_whitelist, const char *if_blacklist)
+static int manager_init(void)
 {
+	struct l_genl *genl = iwd_get_genl();
 	const struct l_settings *config = iwd_get_config();
 	struct l_genl_msg *msg;
 	unsigned int wiphy_dump;
 	unsigned int interface_dump;
 	const char *randomize_str;
+	const char *if_whitelist = iwd_get_iface_whitelist();
+	const char *if_blacklist = iwd_get_iface_blacklist();
 
-	nl80211 = in;
+	nl80211 = l_genl_family_new(genl, NL80211_GENL_NAME);
 
 	if (if_whitelist)
 		whitelist_filter = l_strsplit(if_whitelist, ',');
@@ -606,7 +605,7 @@ bool manager_init(struct l_genl_family *in,
 	if (!l_genl_family_register(nl80211, "config", manager_config_notify,
 					NULL, NULL)) {
 		l_error("Registering for config notifications failed");
-		return false;
+		goto error;
 	}
 
 	msg = l_genl_msg_new_sized(NL80211_CMD_GET_WIPHY, 128);
@@ -617,7 +616,7 @@ bool manager_init(struct l_genl_family *in,
 	if (!wiphy_dump) {
 		l_error("Initial wiphy information dump failed");
 		l_genl_msg_unref(msg);
-		return false;
+		goto error;
 	}
 
 	msg = l_genl_msg_new(NL80211_CMD_GET_INTERFACE);
@@ -629,18 +628,44 @@ bool manager_init(struct l_genl_family *in,
 		l_error("Initial interface information dump failed");
 		l_genl_msg_unref(msg);
 		l_genl_family_cancel(nl80211, wiphy_dump);
-		return false;
+		goto error;
 	}
 
-	randomize_str =
-		l_settings_get_value(config, "General", "mac_randomize");
-	if (randomize_str && !strcmp(randomize_str, "once"))
-		randomize = true;
+	randomize_str = l_settings_get_value(config, "General",
+							"AddressRandomization");
+	if (randomize_str) {
+		if (!strcmp(randomize_str, "once"))
+			randomize = true;
+		else if (!strcmp(randomize_str, "disabled"))
+			randomize = false;
+		else
+			l_warn("Invalid [General].AddressRandomization"
+				" value: %s", randomize_str);
+	}
 
-	return true;
+	if (!l_settings_get_bool(config, "General",
+				"UseDefaultInterface", &use_default)) {
+		if (!l_settings_get_bool(config, "General",
+					"use_default_interface", &use_default))
+			use_default = false;
+		else
+			l_warn("[General].use_default_interface is deprecated"
+					", please use UseDefaultInterface");
+	}
+
+	return 0;
+
+error:
+	l_queue_destroy(pending_wiphys, NULL);
+	pending_wiphys = NULL;
+
+	l_genl_family_free(nl80211);
+	nl80211 = NULL;
+
+	return -EIO;
 }
 
-void manager_exit(void)
+static void manager_exit(void)
 {
 	l_strfreev(whitelist_filter);
 	l_strfreev(blacklist_filter);
@@ -648,6 +673,9 @@ void manager_exit(void)
 	l_queue_destroy(pending_wiphys, wiphy_setup_state_free);
 	pending_wiphys = NULL;
 
+	l_genl_family_free(nl80211);
 	nl80211 = NULL;
 	randomize = false;
 }
+
+IWD_MODULE(manager, manager_init, manager_exit);
